let homeUrl = 'http://localhost:8056',
    timeout = 50000,
    routes = {
        wlPage: homeUrl + '/wp-admin/?page=ti-white-label',
        themes: homeUrl + '/wp-admin/themes.php',
        plugins: homeUrl + '/wp-admin/plugins.php',
    };

describe( 'Test Initialization and white label check.', function() {
    it( 'successfully loads', function() {
        wpLogin(cy);
        wlForm(cy);
        wlCheckTheme(cy);
        wlCheckPlugin(cy);
    } );
} );
/**
 * Log into wordpress
 *
 * @param cy
 */
function wpLogin(cy) {
    cy.visit( homeUrl + '/wp-admin', {
        timeout
    } );
    cy.wait( 500 );
    cy.get( '#user_login' ).type( 'admin' );
    cy.get( '#user_pass' ).type( 'admin' );
    cy.get( '#wp-submit' ).click();
}

/**
 * Fill white label data.
 * @param cy
 */
function wlForm(cy) {
    cy.visit( routes.wlPage, {
        timeout
    } );
    cy.wait( 500 );
    cy.get( '#agency-author' ).clear().type( 'CypressTest' );
    cy.get( '#agency-author-url' ).clear().type( 'https://test.com' );
    cy.get( '#theme-name' ).clear().type( 'CypressTheme' );
    cy.get( '#theme-description' ).clear().type( 'CypressTheme Sample Test' );
    cy.get( '#screenshot-url' ).clear().type( 'https://via.placeholder.com/1200x900/09f/fff.png' );
    cy.get( '#plugin-name' ).clear().type( 'CypressPlugin' );
    cy.get( '#plugin-description' ).clear().type( 'CypressTheme Sample Test' );
    cy.get( '.button-hero' ).click();
}

/**
 * Check theme White Label
 * @param cy
 */
function wlCheckTheme(cy) {
    cy.visit( routes.themes, {
        timeout
    } );
    cy.get( '.theme.active' ).click();

    cy.get('.theme-info .theme-name').should( 'contain', 'CypressTheme' );
    cy.get('.theme-info .theme-author a').should('have.attr', 'href','https://test.com');
    cy.get('.theme-info .theme-author a').should('contain', 'CypressTest' );
    cy.get('.theme-info .theme-description').should('contain','CypressTheme Sample Test');
    cy.get('.theme-screenshots .screenshot img').should('have.attr','src','https://via.placeholder.com/1200x900/09f/fff.png');
}

/**
 * Check plugin White Label
 * @param cy
 */
function wlCheckPlugin(cy) {
    cy.visit( routes.plugins, {
        timeout
    } );

    cy.get('.active .plugin-title').should('contain', 'CypressPlugin' );
    cy.get('.active .plugin-version-author-uri').should('contain', 'CypressTest' );
    cy.get('.active .plugin-version-author-uri a').should('have.attr', 'href','https://test.com');
}
